pascal\_voc\_tools.Augmenter package
====================================

Submodules
----------

pascal\_voc\_tools.Augmenter.bbox\_util module
----------------------------------------------

.. automodule:: pascal_voc_tools.Augmenter.bbox_util
   :members:
   :undoc-members:
   :show-inheritance:

pascal\_voc\_tools.Augmenter.data\_aug module
---------------------------------------------

.. automodule:: pascal_voc_tools.Augmenter.data_aug
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pascal_voc_tools.Augmenter
   :members:
   :undoc-members:
   :show-inheritance:
